From 8828ef598a90c550a9e248e8e0a1d5f88ba017f4 Mon Sep 17 00:00:00 2001
From: "H. Nikolaus Schaller" <hns@goldelico.com>
Date: Sun, 10 May 2015 14:05:06 +0200
Subject: [PATCH] omap4/5 dsi: fix compile error in omap4/5_dsi_mux_pads()

commit 23d34981c7e36fb609d3eaacf0a52a05d75ae008 changed omap4_dsi_mux_pads()
to use regmap_read() and removed omap4_ctrl_pad_readl().

In parallel, some new omap5 function still using omap4_ctrl_pad_readl() was introduced
by commit ddac660564bc72df72be8cdad851e41c19b02bc9 into linux-next.

This leads to a compile error in Linux 4.1-rc1 and -rc2 if OMAP5 DSI is enabled.

This patch fixes the omap5 function to also use regmap_read() and regmap_write().

Signed-off-by: H. Nikolaus Schaller <hns@goldelico.com>
---
 arch/arm/mach-omap2/display.c | 21 ++++++++++++++++++---
 1 file changed, 18 insertions(+), 3 deletions(-)

diff --git a/arch/arm/mach-omap2/display.c b/arch/arm/mach-omap2/display.c
index d8a749f..5b24c7e 100644
--- a/arch/arm/mach-omap2/display.c
+++ b/arch/arm/mach-omap2/display.c
@@ -143,7 +143,22 @@ static int omap4_dsi_mux_pads(int dsi_id, unsigned lanes)
 	return 0;
 }
 
-#define OMAP5_CONTROL_DSIPHY		0x614
+/*
+ * by commit 23d34981c7e36fb609d3eaacf0a52a05d75ae008
+ *
+ * #define OMAP4_CTRL_MODULE_PAD_CORE_CONTROL_DSIPHY       0x0618
+ * did become
+ * #define OMAP4_DSIPHY_SYSCON_OFFSET		0x78
+ *
+ * therefore I guess that
+ * #define OMAP5_CONTROL_DSIPHY           0x614
+ * becomes
+ * #define OMAP5_DSIPHY_SYSCON_OFFSET	0x74
+ *
+ * but I don't know for sure
+ */
+
+#define OMAP5_DSIPHY_SYSCON_OFFSET	0x74
 
 static int omap5_dsi_mux_pads(int dsi_id, unsigned lanes)
 {
@@ -158,10 +173,10 @@ static int omap5_dsi_mux_pads(int dsi_id, unsigned lanes)
 
 	enable_mask = 0x1f << enable_shift;
 
-	reg = omap4_ctrl_pad_readl(OMAP5_CONTROL_DSIPHY);
+	regmap_read(omap4_dsi_mux_syscon, OMAP5_DSIPHY_SYSCON_OFFSET, &reg);
 	reg &= ~enable_mask;
 	reg |= (lanes << enable_shift) & enable_mask;
-	omap4_ctrl_pad_writel(reg, OMAP5_CONTROL_DSIPHY);
+	regmap_write(omap4_dsi_mux_syscon, OMAP5_DSIPHY_SYSCON_OFFSET, reg);
 
 	return 0;
 }
-- 
2.2.1

